#
# spec file for package FlightGear
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           FlightGear
Version:        2017.1.2
Release:        1.3
Summary:        Flight Simulator
License:        GPL-2.0
Group:          Amusements/Games/3D/Simulation
Url:            http://www.flightgear.org/
Source0:        http://downloads.sourceforge.net/project/flightgear/release-2017.1/flightgear-%{version}.tar.bz2
Source1:        %{name}.desktop
Patch0:         explicitely-link-with-libX11.patch
BuildRequires:  SimGear-devel = %{version}
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
Requires:       FlightGear-data = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The FlightGear project is working to create a sophisticated flight
simulator framework for the development and pursuit of interesting
flight simulator ideas. We are developing a solid basic sim that can be
expanded and improved upon by anyone interested in contributing

%prep
%setup -q -n flightgear-%{version}
#%%patch0 -p1

# remove some unneeded doc files
for ext in Cygwin IRIX Joystick Linux MSVC MSVC8 MacOS SimGear Unix Win32-X autoconf mingw plib src xmlsyntax; do
  rm -f docs-mini/README.${ext}
done

%build
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
sed -i -e "s@__DATE__@$DATE@g" -e "s@__TIME__@$TIME@g" utils/fgcom/fgcom.cxx src/FDM/JSBSim/FGJSBBase.cpp

%cmake \
	-DSIMGEAR_SHARED:BOOL=ON \
	-DFG_DATA_DIR:STRING="%{_datadir}/flightgear" \
	-DJPEG_FACTORY:BOOL=ON \
	-DSYSTEM_SQLITE:BOOL=ON
make %{?_smp_mflags}

%install
%cmake_install
# install icons
install -m 0755 -d %{buildroot}%{_datadir}/icons/hicolor/
pushd icons
cp -r -t %{buildroot}%{_datadir}/icons/hicolor/ 16x16 32x32 48x48 64x64 128x128 scalable
popd
# install desktop file
%suse_update_desktop_file -i %{name}
# remove obsolete utilities
cd %{buildroot}%{_bindir} && rm GPSsmooth MIDGsmooth UGsmooth metar yasim

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog NEWS README Thanks docs-mini/*
%{_mandir}/man1/*
%{_bindir}/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/*.svg

%changelog
* Thu Mar  9 2017 wk@ire.pw.edu.pl
- Update to 2017.1.2
* Wed Jan 11 2017 rpm@fthiessen.de
- Update to 2016.4.4
- Removed upstream merged CVE-2016-9956.patch
* Fri Dec 16 2016 thorstenb@flightgear.org
- Applied patch for CVE-2016-9956 (route manager allowed to
  overwrite arbitrary files
* Sun Aug 21 2016 mailaender@opensuse.org
- Update to 2016.2.1
* Sun Mar 20 2016 bosim@opensuse.org
- Added SourceURL
* Mon Mar 14 2016 bosim@opensuse.org
- Update to 2016.1.1
* Tue Nov 24 2015 rpm@fthiessen.de
- Update to 3.7.0
- Added explicitely-link-with-libX11.patch from fedora.
* Mon Sep 23 2013 Mathias.Homann@opensuse.org
- update to 2.12.0
* Tue Mar 19 2013 joop.boonen@opensuse.org
- update to 2.10.0
* Thu Aug 23 2012 thorstenb@flightgear.org
- fix sporadic segfault when listening to ATIS (FlightGear patch
  [#5]ffbb35b)
* Fri Aug 17 2012 thorstenb@flightgear.org
- update to 2.8.0
* Thu May 24 2012 joop.boonen@opensuse.org
- Created gcc47 patch
- Cleaned the spec file up
* Fri Feb 17 2012 thorstenb@flightgear.org
- update to 2.6.0
* Tue Sep  6 2011 highwaystar.ru@gmail.com
- update to 2.4.0
- added patch to use SimGear shared libs
* Wed Apr 13 2011 Rene.vanPaassen@gmail.com
- needed to add -lplibul for openSUSE 11.4
* Tue Apr 12 2011 Rene.vanPaassen@gmail.com
- added a patch to correctly include the plib libraries
* Mon Mar  1 2010 prusnak@suse.cz
- updated to 2.0.0
- apply fixes from Fedora package by Fabrice Bellet <fabrice@bellet.info>
- split off SimGear as a separate package
* Fri Oct 16 2009 prusnak@suse.cz
- updated to 1.9.1
- cleaned spec file
* Tue Jul  1 2008 lmichnovic@suse.cz
- excluding header files in /usr/include/simgear/*
* Tue Jul  1 2008 lmichnovic@suse.cz
- fixed missing include (fgrun-missing_include.patch)
* Mon Jun 30 2008 lmichnovic@suse.cz
- added icons from Josh Babcock (GPL licensed)
- added icon name to desktop file
* Wed Apr 30 2008 lmichnovic@suse.cz
- switched to OSG viewer instead of plib
- enabled jpeg support in Simgear (libjpeg-devel -> BuildReq)
* Mon Apr 28 2008 lmichnovic@suse.cz
- update fgrun to version 1.0.1
  * program internationalized
  * dutch, french, german, italian, polish and portugese localisations
  * fix a crash when "Default" button was pressed
  * fix clock_freeze option
  * added a combo to choose bpp in the wizard
  * added aircraft status and author in the wizard
* Wed Mar  5 2008 lmichnovic@suse.cz
- added fgrun 1.0.0 application as subpackage
  needs fltk-devel in BuildReq
  It needs manual setting ;(
* Thu Jan  3 2008 lmichnovic@suse.cz
- updated FlightGear, SimGear and get_start manual to version 1.0.0
  obsoleted patches SG-include.patch, FG-includes.patch
* Wed Nov 21 2007 lmichnovic@suse.cz
- added OpenSceneGraph-devel to BuildReq
- new subpackage startup-manual which contains manual in pdf
* Tue Oct 16 2007 lmichnovic@suse.cz
- update to cvs version 20071016
- obsoletes FG patches: *64bit.patch, *test.patch
  * array_overflow.patch
- obsoletes SG: *uninitialized.patch
